# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rastervision/protos/tf_object_detection/preprocessor.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rastervision/protos/tf_object_detection/preprocessor.proto',
  package='rastervision.protos.tf_object_detection',
  syntax='proto2',
  serialized_pb=_b('\n:rastervision/protos/tf_object_detection/preprocessor.proto\x12\'rastervision.protos.tf_object_detection\"\x8b\x15\n\x11PreprocessingStep\x12R\n\x0fnormalize_image\x18\x01 \x01(\x0b\x32\x37.rastervision.protos.tf_object_detection.NormalizeImageH\x00\x12_\n\x16random_horizontal_flip\x18\x02 \x01(\x0b\x32=.rastervision.protos.tf_object_detection.RandomHorizontalFlipH\x00\x12\x62\n\x18random_pixel_value_scale\x18\x03 \x01(\x0b\x32>.rastervision.protos.tf_object_detection.RandomPixelValueScaleH\x00\x12W\n\x12random_image_scale\x18\x04 \x01(\x0b\x32\x39.rastervision.protos.tf_object_detection.RandomImageScaleH\x00\x12V\n\x12random_rgb_to_gray\x18\x05 \x01(\x0b\x32\x38.rastervision.protos.tf_object_detection.RandomRGBtoGrayH\x00\x12\x63\n\x18random_adjust_brightness\x18\x06 \x01(\x0b\x32?.rastervision.protos.tf_object_detection.RandomAdjustBrightnessH\x00\x12_\n\x16random_adjust_contrast\x18\x07 \x01(\x0b\x32=.rastervision.protos.tf_object_detection.RandomAdjustContrastH\x00\x12U\n\x11random_adjust_hue\x18\x08 \x01(\x0b\x32\x38.rastervision.protos.tf_object_detection.RandomAdjustHueH\x00\x12\x63\n\x18random_adjust_saturation\x18\t \x01(\x0b\x32?.rastervision.protos.tf_object_detection.RandomAdjustSaturationH\x00\x12[\n\x14random_distort_color\x18\n \x01(\x0b\x32;.rastervision.protos.tf_object_detection.RandomDistortColorH\x00\x12Y\n\x13random_jitter_boxes\x18\x0b \x01(\x0b\x32:.rastervision.protos.tf_object_detection.RandomJitterBoxesH\x00\x12U\n\x11random_crop_image\x18\x0c \x01(\x0b\x32\x38.rastervision.protos.tf_object_detection.RandomCropImageH\x00\x12S\n\x10random_pad_image\x18\r \x01(\x0b\x32\x37.rastervision.protos.tf_object_detection.RandomPadImageH\x00\x12\\\n\x15random_crop_pad_image\x18\x0e \x01(\x0b\x32;.rastervision.protos.tf_object_detection.RandomCropPadImageH\x00\x12g\n\x1brandom_crop_to_aspect_ratio\x18\x0f \x01(\x0b\x32@.rastervision.protos.tf_object_detection.RandomCropToAspectRatioH\x00\x12[\n\x14random_black_patches\x18\x10 \x01(\x0b\x32;.rastervision.protos.tf_object_detection.RandomBlackPatchesH\x00\x12[\n\x14random_resize_method\x18\x11 \x01(\x0b\x32;.rastervision.protos.tf_object_detection.RandomResizeMethodH\x00\x12q\n scale_boxes_to_pixel_coordinates\x18\x12 \x01(\x0b\x32\x45.rastervision.protos.tf_object_detection.ScaleBoxesToPixelCoordinatesH\x00\x12L\n\x0cresize_image\x18\x13 \x01(\x0b\x32\x34.rastervision.protos.tf_object_detection.ResizeImageH\x00\x12]\n\x15subtract_channel_mean\x18\x14 \x01(\x0b\x32<.rastervision.protos.tf_object_detection.SubtractChannelMeanH\x00\x12Q\n\x0fssd_random_crop\x18\x15 \x01(\x0b\x32\x36.rastervision.protos.tf_object_detection.SSDRandomCropH\x00\x12X\n\x13ssd_random_crop_pad\x18\x16 \x01(\x0b\x32\x39.rastervision.protos.tf_object_detection.SSDRandomCropPadH\x00\x12t\n\"ssd_random_crop_fixed_aspect_ratio\x18\x17 \x01(\x0b\x32\x46.rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatioH\x00\x12{\n&ssd_random_crop_pad_fixed_aspect_ratio\x18\x18 \x01(\x0b\x32I.rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatioH\x00\x12[\n\x14random_vertical_flip\x18\x19 \x01(\x0b\x32;.rastervision.protos.tf_object_detection.RandomVerticalFlipH\x00\x12V\n\x11random_rotation90\x18\x1a \x01(\x0b\x32\x39.rastervision.protos.tf_object_detection.RandomRotation90H\x00\x12I\n\x0brgb_to_gray\x18\x1b \x01(\x0b\x32\x32.rastervision.protos.tf_object_detection.RGBtoGrayH\x00\x12o\n\x1f\x63onvert_class_logits_to_softmax\x18\x1c \x01(\x0b\x32\x44.rastervision.protos.tf_object_detection.ConvertClassLogitsToSoftmaxH\x00\x42\x14\n\x12preprocessing_step\"v\n\x0eNormalizeImage\x12\x17\n\x0foriginal_minval\x18\x01 \x01(\x02\x12\x17\n\x0foriginal_maxval\x18\x02 \x01(\x02\x12\x18\n\rtarget_minval\x18\x03 \x01(\x02:\x01\x30\x12\x18\n\rtarget_maxval\x18\x04 \x01(\x02:\x01\x31\"9\n\x14RandomHorizontalFlip\x12!\n\x19keypoint_flip_permutation\x18\x01 \x03(\x05\"7\n\x12RandomVerticalFlip\x12!\n\x19keypoint_flip_permutation\x18\x01 \x03(\x05\"\x12\n\x10RandomRotation90\"A\n\x15RandomPixelValueScale\x12\x13\n\x06minval\x18\x01 \x01(\x02:\x03\x30.9\x12\x13\n\x06maxval\x18\x02 \x01(\x02:\x03\x31.1\"L\n\x10RandomImageScale\x12\x1c\n\x0fmin_scale_ratio\x18\x01 \x01(\x02:\x03\x30.5\x12\x1a\n\x0fmax_scale_ratio\x18\x02 \x01(\x02:\x01\x32\"+\n\x0fRandomRGBtoGray\x12\x18\n\x0bprobability\x18\x01 \x01(\x02:\x03\x30.1\"0\n\x16RandomAdjustBrightness\x12\x16\n\tmax_delta\x18\x01 \x01(\x02:\x03\x30.2\"G\n\x14RandomAdjustContrast\x12\x16\n\tmin_delta\x18\x01 \x01(\x02:\x03\x30.8\x12\x17\n\tmax_delta\x18\x02 \x01(\x02:\x04\x31.25\"*\n\x0fRandomAdjustHue\x12\x17\n\tmax_delta\x18\x01 \x01(\x02:\x04\x30.02\"I\n\x16RandomAdjustSaturation\x12\x16\n\tmin_delta\x18\x01 \x01(\x02:\x03\x30.8\x12\x17\n\tmax_delta\x18\x02 \x01(\x02:\x04\x31.25\",\n\x12RandomDistortColor\x12\x16\n\x0e\x63olor_ordering\x18\x01 \x01(\x05\"(\n\x11RandomJitterBoxes\x12\x13\n\x05ratio\x18\x01 \x01(\x02:\x04\x30.05\"\xd1\x01\n\x0fRandomCropImage\x12\x1d\n\x12min_object_covered\x18\x01 \x01(\x02:\x01\x31\x12\x1e\n\x10min_aspect_ratio\x18\x02 \x01(\x02:\x04\x30.75\x12\x1e\n\x10max_aspect_ratio\x18\x03 \x01(\x02:\x04\x31.33\x12\x15\n\x08min_area\x18\x04 \x01(\x02:\x03\x30.1\x12\x13\n\x08max_area\x18\x05 \x01(\x02:\x01\x31\x12\x1b\n\x0eoverlap_thresh\x18\x06 \x01(\x02:\x03\x30.3\x12\x16\n\x0brandom_coef\x18\x07 \x01(\x02:\x01\x30\"\x89\x01\n\x0eRandomPadImage\x12\x18\n\x10min_image_height\x18\x01 \x01(\x02\x12\x17\n\x0fmin_image_width\x18\x02 \x01(\x02\x12\x18\n\x10max_image_height\x18\x03 \x01(\x02\x12\x17\n\x0fmax_image_width\x18\x04 \x01(\x02\x12\x11\n\tpad_color\x18\x05 \x03(\x02\"\xa5\x02\n\x12RandomCropPadImage\x12\x1d\n\x12min_object_covered\x18\x01 \x01(\x02:\x01\x31\x12\x1e\n\x10min_aspect_ratio\x18\x02 \x01(\x02:\x04\x30.75\x12\x1e\n\x10max_aspect_ratio\x18\x03 \x01(\x02:\x04\x31.33\x12\x15\n\x08min_area\x18\x04 \x01(\x02:\x03\x30.1\x12\x13\n\x08max_area\x18\x05 \x01(\x02:\x01\x31\x12\x1b\n\x0eoverlap_thresh\x18\x06 \x01(\x02:\x03\x30.3\x12\x16\n\x0brandom_coef\x18\x07 \x01(\x02:\x01\x30\x12\x1d\n\x15min_padded_size_ratio\x18\x08 \x03(\x02\x12\x1d\n\x15max_padded_size_ratio\x18\t \x03(\x02\x12\x11\n\tpad_color\x18\n \x03(\x02\"O\n\x17RandomCropToAspectRatio\x12\x17\n\x0c\x61spect_ratio\x18\x01 \x01(\x02:\x01\x31\x12\x1b\n\x0eoverlap_thresh\x18\x02 \x01(\x02:\x03\x30.3\"o\n\x12RandomBlackPatches\x12\x1d\n\x11max_black_patches\x18\x01 \x01(\x05:\x02\x31\x30\x12\x18\n\x0bprobability\x18\x02 \x01(\x02:\x03\x30.5\x12 \n\x13size_to_image_ratio\x18\x03 \x01(\x02:\x03\x30.1\"A\n\x12RandomResizeMethod\x12\x15\n\rtarget_height\x18\x01 \x01(\x02\x12\x14\n\x0ctarget_width\x18\x02 \x01(\x02\"\x0b\n\tRGBtoGray\"\x1e\n\x1cScaleBoxesToPixelCoordinates\"\xd0\x01\n\x0bResizeImage\x12\x12\n\nnew_height\x18\x01 \x01(\x05\x12\x11\n\tnew_width\x18\x02 \x01(\x05\x12U\n\x06method\x18\x03 \x01(\x0e\x32;.rastervision.protos.tf_object_detection.ResizeImage.Method:\x08\x42ILINEAR\"C\n\x06Method\x12\x08\n\x04\x41REA\x10\x01\x12\x0b\n\x07\x42ICUBIC\x10\x02\x12\x0c\n\x08\x42ILINEAR\x10\x03\x12\x14\n\x10NEAREST_NEIGHBOR\x10\x04\"$\n\x13SubtractChannelMean\x12\r\n\x05means\x18\x01 \x03(\x02\"\xb9\x01\n\x16SSDRandomCropOperation\x12\x1a\n\x12min_object_covered\x18\x01 \x01(\x02\x12\x18\n\x10min_aspect_ratio\x18\x02 \x01(\x02\x12\x18\n\x10max_aspect_ratio\x18\x03 \x01(\x02\x12\x10\n\x08min_area\x18\x04 \x01(\x02\x12\x10\n\x08max_area\x18\x05 \x01(\x02\x12\x16\n\x0eoverlap_thresh\x18\x06 \x01(\x02\x12\x13\n\x0brandom_coef\x18\x07 \x01(\x02\"d\n\rSSDRandomCrop\x12S\n\noperations\x18\x01 \x03(\x0b\x32?.rastervision.protos.tf_object_detection.SSDRandomCropOperation\"\xb9\x02\n\x19SSDRandomCropPadOperation\x12\x1a\n\x12min_object_covered\x18\x01 \x01(\x02\x12\x18\n\x10min_aspect_ratio\x18\x02 \x01(\x02\x12\x18\n\x10max_aspect_ratio\x18\x03 \x01(\x02\x12\x10\n\x08min_area\x18\x04 \x01(\x02\x12\x10\n\x08max_area\x18\x05 \x01(\x02\x12\x16\n\x0eoverlap_thresh\x18\x06 \x01(\x02\x12\x13\n\x0brandom_coef\x18\x07 \x01(\x02\x12\x1d\n\x15min_padded_size_ratio\x18\x08 \x03(\x02\x12\x1d\n\x15max_padded_size_ratio\x18\t \x03(\x02\x12\x13\n\x0bpad_color_r\x18\n \x01(\x02\x12\x13\n\x0bpad_color_g\x18\x0b \x01(\x02\x12\x13\n\x0bpad_color_b\x18\x0c \x01(\x02\"j\n\x10SSDRandomCropPad\x12V\n\noperations\x18\x01 \x03(\x0b\x32\x42.rastervision.protos.tf_object_detection.SSDRandomCropPadOperation\"\x95\x01\n&SSDRandomCropFixedAspectRatioOperation\x12\x1a\n\x12min_object_covered\x18\x01 \x01(\x02\x12\x10\n\x08min_area\x18\x04 \x01(\x02\x12\x10\n\x08max_area\x18\x05 \x01(\x02\x12\x16\n\x0eoverlap_thresh\x18\x06 \x01(\x02\x12\x13\n\x0brandom_coef\x18\x07 \x01(\x02\"\x9d\x01\n\x1dSSDRandomCropFixedAspectRatio\x12\x63\n\noperations\x18\x01 \x03(\x0b\x32O.rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatioOperation\x12\x17\n\x0c\x61spect_ratio\x18\x02 \x01(\x02:\x01\x31\"\xcc\x01\n)SSDRandomCropPadFixedAspectRatioOperation\x12\x1a\n\x12min_object_covered\x18\x01 \x01(\x02\x12\x18\n\x10min_aspect_ratio\x18\x02 \x01(\x02\x12\x18\n\x10max_aspect_ratio\x18\x03 \x01(\x02\x12\x10\n\x08min_area\x18\x04 \x01(\x02\x12\x10\n\x08max_area\x18\x05 \x01(\x02\x12\x16\n\x0eoverlap_thresh\x18\x06 \x01(\x02\x12\x13\n\x0brandom_coef\x18\x07 \x01(\x02\"\xe1\x01\n SSDRandomCropPadFixedAspectRatio\x12\x66\n\noperations\x18\x01 \x03(\x0b\x32R.rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatioOperation\x12\x17\n\x0c\x61spect_ratio\x18\x02 \x01(\x02:\x01\x31\x12\x1d\n\x15min_padded_size_ratio\x18\x03 \x03(\x02\x12\x1d\n\x15max_padded_size_ratio\x18\x04 \x03(\x02\"5\n\x1b\x43onvertClassLogitsToSoftmax\x12\x16\n\x0btemperature\x18\x01 \x01(\x02:\x01\x31')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_RESIZEIMAGE_METHOD = _descriptor.EnumDescriptor(
  name='Method',
  full_name='rastervision.protos.tf_object_detection.ResizeImage.Method',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AREA', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BICUBIC', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BILINEAR', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEAREST_NEIGHBOR', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4677,
  serialized_end=4744,
)
_sym_db.RegisterEnumDescriptor(_RESIZEIMAGE_METHOD)


_PREPROCESSINGSTEP = _descriptor.Descriptor(
  name='PreprocessingStep',
  full_name='rastervision.protos.tf_object_detection.PreprocessingStep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='normalize_image', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.normalize_image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_horizontal_flip', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_horizontal_flip', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_pixel_value_scale', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_pixel_value_scale', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_image_scale', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_image_scale', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_rgb_to_gray', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_rgb_to_gray', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_adjust_brightness', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_adjust_brightness', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_adjust_contrast', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_adjust_contrast', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_adjust_hue', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_adjust_hue', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_adjust_saturation', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_adjust_saturation', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_distort_color', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_distort_color', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_jitter_boxes', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_jitter_boxes', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_crop_image', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_crop_image', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_pad_image', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_pad_image', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_crop_pad_image', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_crop_pad_image', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_crop_to_aspect_ratio', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_crop_to_aspect_ratio', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_black_patches', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_black_patches', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_resize_method', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_resize_method', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scale_boxes_to_pixel_coordinates', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.scale_boxes_to_pixel_coordinates', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='resize_image', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.resize_image', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subtract_channel_mean', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.subtract_channel_mean', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ssd_random_crop', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.ssd_random_crop', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ssd_random_crop_pad', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.ssd_random_crop_pad', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ssd_random_crop_fixed_aspect_ratio', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.ssd_random_crop_fixed_aspect_ratio', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ssd_random_crop_pad_fixed_aspect_ratio', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.ssd_random_crop_pad_fixed_aspect_ratio', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_vertical_flip', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_vertical_flip', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_rotation90', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.random_rotation90', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rgb_to_gray', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.rgb_to_gray', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='convert_class_logits_to_softmax', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.convert_class_logits_to_softmax', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='preprocessing_step', full_name='rastervision.protos.tf_object_detection.PreprocessingStep.preprocessing_step',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=104,
  serialized_end=2803,
)


_NORMALIZEIMAGE = _descriptor.Descriptor(
  name='NormalizeImage',
  full_name='rastervision.protos.tf_object_detection.NormalizeImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='original_minval', full_name='rastervision.protos.tf_object_detection.NormalizeImage.original_minval', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='original_maxval', full_name='rastervision.protos.tf_object_detection.NormalizeImage.original_maxval', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_minval', full_name='rastervision.protos.tf_object_detection.NormalizeImage.target_minval', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_maxval', full_name='rastervision.protos.tf_object_detection.NormalizeImage.target_maxval', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2805,
  serialized_end=2923,
)


_RANDOMHORIZONTALFLIP = _descriptor.Descriptor(
  name='RandomHorizontalFlip',
  full_name='rastervision.protos.tf_object_detection.RandomHorizontalFlip',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keypoint_flip_permutation', full_name='rastervision.protos.tf_object_detection.RandomHorizontalFlip.keypoint_flip_permutation', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2925,
  serialized_end=2982,
)


_RANDOMVERTICALFLIP = _descriptor.Descriptor(
  name='RandomVerticalFlip',
  full_name='rastervision.protos.tf_object_detection.RandomVerticalFlip',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keypoint_flip_permutation', full_name='rastervision.protos.tf_object_detection.RandomVerticalFlip.keypoint_flip_permutation', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2984,
  serialized_end=3039,
)


_RANDOMROTATION90 = _descriptor.Descriptor(
  name='RandomRotation90',
  full_name='rastervision.protos.tf_object_detection.RandomRotation90',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3041,
  serialized_end=3059,
)


_RANDOMPIXELVALUESCALE = _descriptor.Descriptor(
  name='RandomPixelValueScale',
  full_name='rastervision.protos.tf_object_detection.RandomPixelValueScale',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='minval', full_name='rastervision.protos.tf_object_detection.RandomPixelValueScale.minval', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.9),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxval', full_name='rastervision.protos.tf_object_detection.RandomPixelValueScale.maxval', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3061,
  serialized_end=3126,
)


_RANDOMIMAGESCALE = _descriptor.Descriptor(
  name='RandomImageScale',
  full_name='rastervision.protos.tf_object_detection.RandomImageScale',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_scale_ratio', full_name='rastervision.protos.tf_object_detection.RandomImageScale.min_scale_ratio', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_scale_ratio', full_name='rastervision.protos.tf_object_detection.RandomImageScale.max_scale_ratio', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3128,
  serialized_end=3204,
)


_RANDOMRGBTOGRAY = _descriptor.Descriptor(
  name='RandomRGBtoGray',
  full_name='rastervision.protos.tf_object_detection.RandomRGBtoGray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='probability', full_name='rastervision.protos.tf_object_detection.RandomRGBtoGray.probability', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3206,
  serialized_end=3249,
)


_RANDOMADJUSTBRIGHTNESS = _descriptor.Descriptor(
  name='RandomAdjustBrightness',
  full_name='rastervision.protos.tf_object_detection.RandomAdjustBrightness',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_delta', full_name='rastervision.protos.tf_object_detection.RandomAdjustBrightness.max_delta', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3251,
  serialized_end=3299,
)


_RANDOMADJUSTCONTRAST = _descriptor.Descriptor(
  name='RandomAdjustContrast',
  full_name='rastervision.protos.tf_object_detection.RandomAdjustContrast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_delta', full_name='rastervision.protos.tf_object_detection.RandomAdjustContrast.min_delta', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.8),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_delta', full_name='rastervision.protos.tf_object_detection.RandomAdjustContrast.max_delta', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1.25),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3301,
  serialized_end=3372,
)


_RANDOMADJUSTHUE = _descriptor.Descriptor(
  name='RandomAdjustHue',
  full_name='rastervision.protos.tf_object_detection.RandomAdjustHue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_delta', full_name='rastervision.protos.tf_object_detection.RandomAdjustHue.max_delta', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.02),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3374,
  serialized_end=3416,
)


_RANDOMADJUSTSATURATION = _descriptor.Descriptor(
  name='RandomAdjustSaturation',
  full_name='rastervision.protos.tf_object_detection.RandomAdjustSaturation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_delta', full_name='rastervision.protos.tf_object_detection.RandomAdjustSaturation.min_delta', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.8),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_delta', full_name='rastervision.protos.tf_object_detection.RandomAdjustSaturation.max_delta', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1.25),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3418,
  serialized_end=3491,
)


_RANDOMDISTORTCOLOR = _descriptor.Descriptor(
  name='RandomDistortColor',
  full_name='rastervision.protos.tf_object_detection.RandomDistortColor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color_ordering', full_name='rastervision.protos.tf_object_detection.RandomDistortColor.color_ordering', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3493,
  serialized_end=3537,
)


_RANDOMJITTERBOXES = _descriptor.Descriptor(
  name='RandomJitterBoxes',
  full_name='rastervision.protos.tf_object_detection.RandomJitterBoxes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ratio', full_name='rastervision.protos.tf_object_detection.RandomJitterBoxes.ratio', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.05),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3539,
  serialized_end=3579,
)


_RANDOMCROPIMAGE = _descriptor.Descriptor(
  name='RandomCropImage',
  full_name='rastervision.protos.tf_object_detection.RandomCropImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_object_covered', full_name='rastervision.protos.tf_object_detection.RandomCropImage.min_object_covered', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_aspect_ratio', full_name='rastervision.protos.tf_object_detection.RandomCropImage.min_aspect_ratio', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.75),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_aspect_ratio', full_name='rastervision.protos.tf_object_detection.RandomCropImage.max_aspect_ratio', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1.33),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_area', full_name='rastervision.protos.tf_object_detection.RandomCropImage.min_area', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_area', full_name='rastervision.protos.tf_object_detection.RandomCropImage.max_area', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='overlap_thresh', full_name='rastervision.protos.tf_object_detection.RandomCropImage.overlap_thresh', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_coef', full_name='rastervision.protos.tf_object_detection.RandomCropImage.random_coef', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3582,
  serialized_end=3791,
)


_RANDOMPADIMAGE = _descriptor.Descriptor(
  name='RandomPadImage',
  full_name='rastervision.protos.tf_object_detection.RandomPadImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_image_height', full_name='rastervision.protos.tf_object_detection.RandomPadImage.min_image_height', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_image_width', full_name='rastervision.protos.tf_object_detection.RandomPadImage.min_image_width', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_image_height', full_name='rastervision.protos.tf_object_detection.RandomPadImage.max_image_height', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_image_width', full_name='rastervision.protos.tf_object_detection.RandomPadImage.max_image_width', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pad_color', full_name='rastervision.protos.tf_object_detection.RandomPadImage.pad_color', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3794,
  serialized_end=3931,
)


_RANDOMCROPPADIMAGE = _descriptor.Descriptor(
  name='RandomCropPadImage',
  full_name='rastervision.protos.tf_object_detection.RandomCropPadImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_object_covered', full_name='rastervision.protos.tf_object_detection.RandomCropPadImage.min_object_covered', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_aspect_ratio', full_name='rastervision.protos.tf_object_detection.RandomCropPadImage.min_aspect_ratio', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.75),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_aspect_ratio', full_name='rastervision.protos.tf_object_detection.RandomCropPadImage.max_aspect_ratio', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1.33),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_area', full_name='rastervision.protos.tf_object_detection.RandomCropPadImage.min_area', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_area', full_name='rastervision.protos.tf_object_detection.RandomCropPadImage.max_area', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='overlap_thresh', full_name='rastervision.protos.tf_object_detection.RandomCropPadImage.overlap_thresh', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_coef', full_name='rastervision.protos.tf_object_detection.RandomCropPadImage.random_coef', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_padded_size_ratio', full_name='rastervision.protos.tf_object_detection.RandomCropPadImage.min_padded_size_ratio', index=7,
      number=8, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_padded_size_ratio', full_name='rastervision.protos.tf_object_detection.RandomCropPadImage.max_padded_size_ratio', index=8,
      number=9, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pad_color', full_name='rastervision.protos.tf_object_detection.RandomCropPadImage.pad_color', index=9,
      number=10, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3934,
  serialized_end=4227,
)


_RANDOMCROPTOASPECTRATIO = _descriptor.Descriptor(
  name='RandomCropToAspectRatio',
  full_name='rastervision.protos.tf_object_detection.RandomCropToAspectRatio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aspect_ratio', full_name='rastervision.protos.tf_object_detection.RandomCropToAspectRatio.aspect_ratio', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='overlap_thresh', full_name='rastervision.protos.tf_object_detection.RandomCropToAspectRatio.overlap_thresh', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4229,
  serialized_end=4308,
)


_RANDOMBLACKPATCHES = _descriptor.Descriptor(
  name='RandomBlackPatches',
  full_name='rastervision.protos.tf_object_detection.RandomBlackPatches',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_black_patches', full_name='rastervision.protos.tf_object_detection.RandomBlackPatches.max_black_patches', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probability', full_name='rastervision.protos.tf_object_detection.RandomBlackPatches.probability', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='size_to_image_ratio', full_name='rastervision.protos.tf_object_detection.RandomBlackPatches.size_to_image_ratio', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4310,
  serialized_end=4421,
)


_RANDOMRESIZEMETHOD = _descriptor.Descriptor(
  name='RandomResizeMethod',
  full_name='rastervision.protos.tf_object_detection.RandomResizeMethod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_height', full_name='rastervision.protos.tf_object_detection.RandomResizeMethod.target_height', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_width', full_name='rastervision.protos.tf_object_detection.RandomResizeMethod.target_width', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4423,
  serialized_end=4488,
)


_RGBTOGRAY = _descriptor.Descriptor(
  name='RGBtoGray',
  full_name='rastervision.protos.tf_object_detection.RGBtoGray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4490,
  serialized_end=4501,
)


_SCALEBOXESTOPIXELCOORDINATES = _descriptor.Descriptor(
  name='ScaleBoxesToPixelCoordinates',
  full_name='rastervision.protos.tf_object_detection.ScaleBoxesToPixelCoordinates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4503,
  serialized_end=4533,
)


_RESIZEIMAGE = _descriptor.Descriptor(
  name='ResizeImage',
  full_name='rastervision.protos.tf_object_detection.ResizeImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_height', full_name='rastervision.protos.tf_object_detection.ResizeImage.new_height', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_width', full_name='rastervision.protos.tf_object_detection.ResizeImage.new_width', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='method', full_name='rastervision.protos.tf_object_detection.ResizeImage.method', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RESIZEIMAGE_METHOD,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4536,
  serialized_end=4744,
)


_SUBTRACTCHANNELMEAN = _descriptor.Descriptor(
  name='SubtractChannelMean',
  full_name='rastervision.protos.tf_object_detection.SubtractChannelMean',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='means', full_name='rastervision.protos.tf_object_detection.SubtractChannelMean.means', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4746,
  serialized_end=4782,
)


_SSDRANDOMCROPOPERATION = _descriptor.Descriptor(
  name='SSDRandomCropOperation',
  full_name='rastervision.protos.tf_object_detection.SSDRandomCropOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_object_covered', full_name='rastervision.protos.tf_object_detection.SSDRandomCropOperation.min_object_covered', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_aspect_ratio', full_name='rastervision.protos.tf_object_detection.SSDRandomCropOperation.min_aspect_ratio', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_aspect_ratio', full_name='rastervision.protos.tf_object_detection.SSDRandomCropOperation.max_aspect_ratio', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_area', full_name='rastervision.protos.tf_object_detection.SSDRandomCropOperation.min_area', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_area', full_name='rastervision.protos.tf_object_detection.SSDRandomCropOperation.max_area', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='overlap_thresh', full_name='rastervision.protos.tf_object_detection.SSDRandomCropOperation.overlap_thresh', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_coef', full_name='rastervision.protos.tf_object_detection.SSDRandomCropOperation.random_coef', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4785,
  serialized_end=4970,
)


_SSDRANDOMCROP = _descriptor.Descriptor(
  name='SSDRandomCrop',
  full_name='rastervision.protos.tf_object_detection.SSDRandomCrop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='rastervision.protos.tf_object_detection.SSDRandomCrop.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4972,
  serialized_end=5072,
)


_SSDRANDOMCROPPADOPERATION = _descriptor.Descriptor(
  name='SSDRandomCropPadOperation',
  full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_object_covered', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation.min_object_covered', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_aspect_ratio', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation.min_aspect_ratio', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_aspect_ratio', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation.max_aspect_ratio', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_area', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation.min_area', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_area', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation.max_area', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='overlap_thresh', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation.overlap_thresh', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_coef', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation.random_coef', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_padded_size_ratio', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation.min_padded_size_ratio', index=7,
      number=8, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_padded_size_ratio', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation.max_padded_size_ratio', index=8,
      number=9, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pad_color_r', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation.pad_color_r', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pad_color_g', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation.pad_color_g', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pad_color_b', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadOperation.pad_color_b', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5075,
  serialized_end=5388,
)


_SSDRANDOMCROPPAD = _descriptor.Descriptor(
  name='SSDRandomCropPad',
  full_name='rastervision.protos.tf_object_detection.SSDRandomCropPad',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPad.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5390,
  serialized_end=5496,
)


_SSDRANDOMCROPFIXEDASPECTRATIOOPERATION = _descriptor.Descriptor(
  name='SSDRandomCropFixedAspectRatioOperation',
  full_name='rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatioOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_object_covered', full_name='rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatioOperation.min_object_covered', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_area', full_name='rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatioOperation.min_area', index=1,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_area', full_name='rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatioOperation.max_area', index=2,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='overlap_thresh', full_name='rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatioOperation.overlap_thresh', index=3,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_coef', full_name='rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatioOperation.random_coef', index=4,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5499,
  serialized_end=5648,
)


_SSDRANDOMCROPFIXEDASPECTRATIO = _descriptor.Descriptor(
  name='SSDRandomCropFixedAspectRatio',
  full_name='rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatio.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aspect_ratio', full_name='rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatio.aspect_ratio', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5651,
  serialized_end=5808,
)


_SSDRANDOMCROPPADFIXEDASPECTRATIOOPERATION = _descriptor.Descriptor(
  name='SSDRandomCropPadFixedAspectRatioOperation',
  full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatioOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_object_covered', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatioOperation.min_object_covered', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_aspect_ratio', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatioOperation.min_aspect_ratio', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_aspect_ratio', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatioOperation.max_aspect_ratio', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_area', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatioOperation.min_area', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_area', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatioOperation.max_area', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='overlap_thresh', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatioOperation.overlap_thresh', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='random_coef', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatioOperation.random_coef', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5811,
  serialized_end=6015,
)


_SSDRANDOMCROPPADFIXEDASPECTRATIO = _descriptor.Descriptor(
  name='SSDRandomCropPadFixedAspectRatio',
  full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatio.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aspect_ratio', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatio.aspect_ratio', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_padded_size_ratio', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatio.min_padded_size_ratio', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_padded_size_ratio', full_name='rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatio.max_padded_size_ratio', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6018,
  serialized_end=6243,
)


_CONVERTCLASSLOGITSTOSOFTMAX = _descriptor.Descriptor(
  name='ConvertClassLogitsToSoftmax',
  full_name='rastervision.protos.tf_object_detection.ConvertClassLogitsToSoftmax',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='temperature', full_name='rastervision.protos.tf_object_detection.ConvertClassLogitsToSoftmax.temperature', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6245,
  serialized_end=6298,
)

_PREPROCESSINGSTEP.fields_by_name['normalize_image'].message_type = _NORMALIZEIMAGE
_PREPROCESSINGSTEP.fields_by_name['random_horizontal_flip'].message_type = _RANDOMHORIZONTALFLIP
_PREPROCESSINGSTEP.fields_by_name['random_pixel_value_scale'].message_type = _RANDOMPIXELVALUESCALE
_PREPROCESSINGSTEP.fields_by_name['random_image_scale'].message_type = _RANDOMIMAGESCALE
_PREPROCESSINGSTEP.fields_by_name['random_rgb_to_gray'].message_type = _RANDOMRGBTOGRAY
_PREPROCESSINGSTEP.fields_by_name['random_adjust_brightness'].message_type = _RANDOMADJUSTBRIGHTNESS
_PREPROCESSINGSTEP.fields_by_name['random_adjust_contrast'].message_type = _RANDOMADJUSTCONTRAST
_PREPROCESSINGSTEP.fields_by_name['random_adjust_hue'].message_type = _RANDOMADJUSTHUE
_PREPROCESSINGSTEP.fields_by_name['random_adjust_saturation'].message_type = _RANDOMADJUSTSATURATION
_PREPROCESSINGSTEP.fields_by_name['random_distort_color'].message_type = _RANDOMDISTORTCOLOR
_PREPROCESSINGSTEP.fields_by_name['random_jitter_boxes'].message_type = _RANDOMJITTERBOXES
_PREPROCESSINGSTEP.fields_by_name['random_crop_image'].message_type = _RANDOMCROPIMAGE
_PREPROCESSINGSTEP.fields_by_name['random_pad_image'].message_type = _RANDOMPADIMAGE
_PREPROCESSINGSTEP.fields_by_name['random_crop_pad_image'].message_type = _RANDOMCROPPADIMAGE
_PREPROCESSINGSTEP.fields_by_name['random_crop_to_aspect_ratio'].message_type = _RANDOMCROPTOASPECTRATIO
_PREPROCESSINGSTEP.fields_by_name['random_black_patches'].message_type = _RANDOMBLACKPATCHES
_PREPROCESSINGSTEP.fields_by_name['random_resize_method'].message_type = _RANDOMRESIZEMETHOD
_PREPROCESSINGSTEP.fields_by_name['scale_boxes_to_pixel_coordinates'].message_type = _SCALEBOXESTOPIXELCOORDINATES
_PREPROCESSINGSTEP.fields_by_name['resize_image'].message_type = _RESIZEIMAGE
_PREPROCESSINGSTEP.fields_by_name['subtract_channel_mean'].message_type = _SUBTRACTCHANNELMEAN
_PREPROCESSINGSTEP.fields_by_name['ssd_random_crop'].message_type = _SSDRANDOMCROP
_PREPROCESSINGSTEP.fields_by_name['ssd_random_crop_pad'].message_type = _SSDRANDOMCROPPAD
_PREPROCESSINGSTEP.fields_by_name['ssd_random_crop_fixed_aspect_ratio'].message_type = _SSDRANDOMCROPFIXEDASPECTRATIO
_PREPROCESSINGSTEP.fields_by_name['ssd_random_crop_pad_fixed_aspect_ratio'].message_type = _SSDRANDOMCROPPADFIXEDASPECTRATIO
_PREPROCESSINGSTEP.fields_by_name['random_vertical_flip'].message_type = _RANDOMVERTICALFLIP
_PREPROCESSINGSTEP.fields_by_name['random_rotation90'].message_type = _RANDOMROTATION90
_PREPROCESSINGSTEP.fields_by_name['rgb_to_gray'].message_type = _RGBTOGRAY
_PREPROCESSINGSTEP.fields_by_name['convert_class_logits_to_softmax'].message_type = _CONVERTCLASSLOGITSTOSOFTMAX
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['normalize_image'])
_PREPROCESSINGSTEP.fields_by_name['normalize_image'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_horizontal_flip'])
_PREPROCESSINGSTEP.fields_by_name['random_horizontal_flip'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_pixel_value_scale'])
_PREPROCESSINGSTEP.fields_by_name['random_pixel_value_scale'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_image_scale'])
_PREPROCESSINGSTEP.fields_by_name['random_image_scale'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_rgb_to_gray'])
_PREPROCESSINGSTEP.fields_by_name['random_rgb_to_gray'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_adjust_brightness'])
_PREPROCESSINGSTEP.fields_by_name['random_adjust_brightness'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_adjust_contrast'])
_PREPROCESSINGSTEP.fields_by_name['random_adjust_contrast'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_adjust_hue'])
_PREPROCESSINGSTEP.fields_by_name['random_adjust_hue'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_adjust_saturation'])
_PREPROCESSINGSTEP.fields_by_name['random_adjust_saturation'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_distort_color'])
_PREPROCESSINGSTEP.fields_by_name['random_distort_color'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_jitter_boxes'])
_PREPROCESSINGSTEP.fields_by_name['random_jitter_boxes'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_crop_image'])
_PREPROCESSINGSTEP.fields_by_name['random_crop_image'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_pad_image'])
_PREPROCESSINGSTEP.fields_by_name['random_pad_image'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_crop_pad_image'])
_PREPROCESSINGSTEP.fields_by_name['random_crop_pad_image'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_crop_to_aspect_ratio'])
_PREPROCESSINGSTEP.fields_by_name['random_crop_to_aspect_ratio'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_black_patches'])
_PREPROCESSINGSTEP.fields_by_name['random_black_patches'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_resize_method'])
_PREPROCESSINGSTEP.fields_by_name['random_resize_method'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['scale_boxes_to_pixel_coordinates'])
_PREPROCESSINGSTEP.fields_by_name['scale_boxes_to_pixel_coordinates'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['resize_image'])
_PREPROCESSINGSTEP.fields_by_name['resize_image'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['subtract_channel_mean'])
_PREPROCESSINGSTEP.fields_by_name['subtract_channel_mean'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['ssd_random_crop'])
_PREPROCESSINGSTEP.fields_by_name['ssd_random_crop'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['ssd_random_crop_pad'])
_PREPROCESSINGSTEP.fields_by_name['ssd_random_crop_pad'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['ssd_random_crop_fixed_aspect_ratio'])
_PREPROCESSINGSTEP.fields_by_name['ssd_random_crop_fixed_aspect_ratio'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['ssd_random_crop_pad_fixed_aspect_ratio'])
_PREPROCESSINGSTEP.fields_by_name['ssd_random_crop_pad_fixed_aspect_ratio'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_vertical_flip'])
_PREPROCESSINGSTEP.fields_by_name['random_vertical_flip'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['random_rotation90'])
_PREPROCESSINGSTEP.fields_by_name['random_rotation90'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['rgb_to_gray'])
_PREPROCESSINGSTEP.fields_by_name['rgb_to_gray'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step'].fields.append(
  _PREPROCESSINGSTEP.fields_by_name['convert_class_logits_to_softmax'])
_PREPROCESSINGSTEP.fields_by_name['convert_class_logits_to_softmax'].containing_oneof = _PREPROCESSINGSTEP.oneofs_by_name['preprocessing_step']
_RESIZEIMAGE.fields_by_name['method'].enum_type = _RESIZEIMAGE_METHOD
_RESIZEIMAGE_METHOD.containing_type = _RESIZEIMAGE
_SSDRANDOMCROP.fields_by_name['operations'].message_type = _SSDRANDOMCROPOPERATION
_SSDRANDOMCROPPAD.fields_by_name['operations'].message_type = _SSDRANDOMCROPPADOPERATION
_SSDRANDOMCROPFIXEDASPECTRATIO.fields_by_name['operations'].message_type = _SSDRANDOMCROPFIXEDASPECTRATIOOPERATION
_SSDRANDOMCROPPADFIXEDASPECTRATIO.fields_by_name['operations'].message_type = _SSDRANDOMCROPPADFIXEDASPECTRATIOOPERATION
DESCRIPTOR.message_types_by_name['PreprocessingStep'] = _PREPROCESSINGSTEP
DESCRIPTOR.message_types_by_name['NormalizeImage'] = _NORMALIZEIMAGE
DESCRIPTOR.message_types_by_name['RandomHorizontalFlip'] = _RANDOMHORIZONTALFLIP
DESCRIPTOR.message_types_by_name['RandomVerticalFlip'] = _RANDOMVERTICALFLIP
DESCRIPTOR.message_types_by_name['RandomRotation90'] = _RANDOMROTATION90
DESCRIPTOR.message_types_by_name['RandomPixelValueScale'] = _RANDOMPIXELVALUESCALE
DESCRIPTOR.message_types_by_name['RandomImageScale'] = _RANDOMIMAGESCALE
DESCRIPTOR.message_types_by_name['RandomRGBtoGray'] = _RANDOMRGBTOGRAY
DESCRIPTOR.message_types_by_name['RandomAdjustBrightness'] = _RANDOMADJUSTBRIGHTNESS
DESCRIPTOR.message_types_by_name['RandomAdjustContrast'] = _RANDOMADJUSTCONTRAST
DESCRIPTOR.message_types_by_name['RandomAdjustHue'] = _RANDOMADJUSTHUE
DESCRIPTOR.message_types_by_name['RandomAdjustSaturation'] = _RANDOMADJUSTSATURATION
DESCRIPTOR.message_types_by_name['RandomDistortColor'] = _RANDOMDISTORTCOLOR
DESCRIPTOR.message_types_by_name['RandomJitterBoxes'] = _RANDOMJITTERBOXES
DESCRIPTOR.message_types_by_name['RandomCropImage'] = _RANDOMCROPIMAGE
DESCRIPTOR.message_types_by_name['RandomPadImage'] = _RANDOMPADIMAGE
DESCRIPTOR.message_types_by_name['RandomCropPadImage'] = _RANDOMCROPPADIMAGE
DESCRIPTOR.message_types_by_name['RandomCropToAspectRatio'] = _RANDOMCROPTOASPECTRATIO
DESCRIPTOR.message_types_by_name['RandomBlackPatches'] = _RANDOMBLACKPATCHES
DESCRIPTOR.message_types_by_name['RandomResizeMethod'] = _RANDOMRESIZEMETHOD
DESCRIPTOR.message_types_by_name['RGBtoGray'] = _RGBTOGRAY
DESCRIPTOR.message_types_by_name['ScaleBoxesToPixelCoordinates'] = _SCALEBOXESTOPIXELCOORDINATES
DESCRIPTOR.message_types_by_name['ResizeImage'] = _RESIZEIMAGE
DESCRIPTOR.message_types_by_name['SubtractChannelMean'] = _SUBTRACTCHANNELMEAN
DESCRIPTOR.message_types_by_name['SSDRandomCropOperation'] = _SSDRANDOMCROPOPERATION
DESCRIPTOR.message_types_by_name['SSDRandomCrop'] = _SSDRANDOMCROP
DESCRIPTOR.message_types_by_name['SSDRandomCropPadOperation'] = _SSDRANDOMCROPPADOPERATION
DESCRIPTOR.message_types_by_name['SSDRandomCropPad'] = _SSDRANDOMCROPPAD
DESCRIPTOR.message_types_by_name['SSDRandomCropFixedAspectRatioOperation'] = _SSDRANDOMCROPFIXEDASPECTRATIOOPERATION
DESCRIPTOR.message_types_by_name['SSDRandomCropFixedAspectRatio'] = _SSDRANDOMCROPFIXEDASPECTRATIO
DESCRIPTOR.message_types_by_name['SSDRandomCropPadFixedAspectRatioOperation'] = _SSDRANDOMCROPPADFIXEDASPECTRATIOOPERATION
DESCRIPTOR.message_types_by_name['SSDRandomCropPadFixedAspectRatio'] = _SSDRANDOMCROPPADFIXEDASPECTRATIO
DESCRIPTOR.message_types_by_name['ConvertClassLogitsToSoftmax'] = _CONVERTCLASSLOGITSTOSOFTMAX

PreprocessingStep = _reflection.GeneratedProtocolMessageType('PreprocessingStep', (_message.Message,), dict(
  DESCRIPTOR = _PREPROCESSINGSTEP,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.PreprocessingStep)
  ))
_sym_db.RegisterMessage(PreprocessingStep)

NormalizeImage = _reflection.GeneratedProtocolMessageType('NormalizeImage', (_message.Message,), dict(
  DESCRIPTOR = _NORMALIZEIMAGE,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.NormalizeImage)
  ))
_sym_db.RegisterMessage(NormalizeImage)

RandomHorizontalFlip = _reflection.GeneratedProtocolMessageType('RandomHorizontalFlip', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMHORIZONTALFLIP,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomHorizontalFlip)
  ))
_sym_db.RegisterMessage(RandomHorizontalFlip)

RandomVerticalFlip = _reflection.GeneratedProtocolMessageType('RandomVerticalFlip', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMVERTICALFLIP,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomVerticalFlip)
  ))
_sym_db.RegisterMessage(RandomVerticalFlip)

RandomRotation90 = _reflection.GeneratedProtocolMessageType('RandomRotation90', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMROTATION90,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomRotation90)
  ))
_sym_db.RegisterMessage(RandomRotation90)

RandomPixelValueScale = _reflection.GeneratedProtocolMessageType('RandomPixelValueScale', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMPIXELVALUESCALE,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomPixelValueScale)
  ))
_sym_db.RegisterMessage(RandomPixelValueScale)

RandomImageScale = _reflection.GeneratedProtocolMessageType('RandomImageScale', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMIMAGESCALE,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomImageScale)
  ))
_sym_db.RegisterMessage(RandomImageScale)

RandomRGBtoGray = _reflection.GeneratedProtocolMessageType('RandomRGBtoGray', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMRGBTOGRAY,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomRGBtoGray)
  ))
_sym_db.RegisterMessage(RandomRGBtoGray)

RandomAdjustBrightness = _reflection.GeneratedProtocolMessageType('RandomAdjustBrightness', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMADJUSTBRIGHTNESS,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomAdjustBrightness)
  ))
_sym_db.RegisterMessage(RandomAdjustBrightness)

RandomAdjustContrast = _reflection.GeneratedProtocolMessageType('RandomAdjustContrast', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMADJUSTCONTRAST,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomAdjustContrast)
  ))
_sym_db.RegisterMessage(RandomAdjustContrast)

RandomAdjustHue = _reflection.GeneratedProtocolMessageType('RandomAdjustHue', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMADJUSTHUE,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomAdjustHue)
  ))
_sym_db.RegisterMessage(RandomAdjustHue)

RandomAdjustSaturation = _reflection.GeneratedProtocolMessageType('RandomAdjustSaturation', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMADJUSTSATURATION,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomAdjustSaturation)
  ))
_sym_db.RegisterMessage(RandomAdjustSaturation)

RandomDistortColor = _reflection.GeneratedProtocolMessageType('RandomDistortColor', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMDISTORTCOLOR,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomDistortColor)
  ))
_sym_db.RegisterMessage(RandomDistortColor)

RandomJitterBoxes = _reflection.GeneratedProtocolMessageType('RandomJitterBoxes', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMJITTERBOXES,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomJitterBoxes)
  ))
_sym_db.RegisterMessage(RandomJitterBoxes)

RandomCropImage = _reflection.GeneratedProtocolMessageType('RandomCropImage', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMCROPIMAGE,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomCropImage)
  ))
_sym_db.RegisterMessage(RandomCropImage)

RandomPadImage = _reflection.GeneratedProtocolMessageType('RandomPadImage', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMPADIMAGE,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomPadImage)
  ))
_sym_db.RegisterMessage(RandomPadImage)

RandomCropPadImage = _reflection.GeneratedProtocolMessageType('RandomCropPadImage', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMCROPPADIMAGE,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomCropPadImage)
  ))
_sym_db.RegisterMessage(RandomCropPadImage)

RandomCropToAspectRatio = _reflection.GeneratedProtocolMessageType('RandomCropToAspectRatio', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMCROPTOASPECTRATIO,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomCropToAspectRatio)
  ))
_sym_db.RegisterMessage(RandomCropToAspectRatio)

RandomBlackPatches = _reflection.GeneratedProtocolMessageType('RandomBlackPatches', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMBLACKPATCHES,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomBlackPatches)
  ))
_sym_db.RegisterMessage(RandomBlackPatches)

RandomResizeMethod = _reflection.GeneratedProtocolMessageType('RandomResizeMethod', (_message.Message,), dict(
  DESCRIPTOR = _RANDOMRESIZEMETHOD,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RandomResizeMethod)
  ))
_sym_db.RegisterMessage(RandomResizeMethod)

RGBtoGray = _reflection.GeneratedProtocolMessageType('RGBtoGray', (_message.Message,), dict(
  DESCRIPTOR = _RGBTOGRAY,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.RGBtoGray)
  ))
_sym_db.RegisterMessage(RGBtoGray)

ScaleBoxesToPixelCoordinates = _reflection.GeneratedProtocolMessageType('ScaleBoxesToPixelCoordinates', (_message.Message,), dict(
  DESCRIPTOR = _SCALEBOXESTOPIXELCOORDINATES,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.ScaleBoxesToPixelCoordinates)
  ))
_sym_db.RegisterMessage(ScaleBoxesToPixelCoordinates)

ResizeImage = _reflection.GeneratedProtocolMessageType('ResizeImage', (_message.Message,), dict(
  DESCRIPTOR = _RESIZEIMAGE,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.ResizeImage)
  ))
_sym_db.RegisterMessage(ResizeImage)

SubtractChannelMean = _reflection.GeneratedProtocolMessageType('SubtractChannelMean', (_message.Message,), dict(
  DESCRIPTOR = _SUBTRACTCHANNELMEAN,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.SubtractChannelMean)
  ))
_sym_db.RegisterMessage(SubtractChannelMean)

SSDRandomCropOperation = _reflection.GeneratedProtocolMessageType('SSDRandomCropOperation', (_message.Message,), dict(
  DESCRIPTOR = _SSDRANDOMCROPOPERATION,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.SSDRandomCropOperation)
  ))
_sym_db.RegisterMessage(SSDRandomCropOperation)

SSDRandomCrop = _reflection.GeneratedProtocolMessageType('SSDRandomCrop', (_message.Message,), dict(
  DESCRIPTOR = _SSDRANDOMCROP,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.SSDRandomCrop)
  ))
_sym_db.RegisterMessage(SSDRandomCrop)

SSDRandomCropPadOperation = _reflection.GeneratedProtocolMessageType('SSDRandomCropPadOperation', (_message.Message,), dict(
  DESCRIPTOR = _SSDRANDOMCROPPADOPERATION,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.SSDRandomCropPadOperation)
  ))
_sym_db.RegisterMessage(SSDRandomCropPadOperation)

SSDRandomCropPad = _reflection.GeneratedProtocolMessageType('SSDRandomCropPad', (_message.Message,), dict(
  DESCRIPTOR = _SSDRANDOMCROPPAD,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.SSDRandomCropPad)
  ))
_sym_db.RegisterMessage(SSDRandomCropPad)

SSDRandomCropFixedAspectRatioOperation = _reflection.GeneratedProtocolMessageType('SSDRandomCropFixedAspectRatioOperation', (_message.Message,), dict(
  DESCRIPTOR = _SSDRANDOMCROPFIXEDASPECTRATIOOPERATION,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatioOperation)
  ))
_sym_db.RegisterMessage(SSDRandomCropFixedAspectRatioOperation)

SSDRandomCropFixedAspectRatio = _reflection.GeneratedProtocolMessageType('SSDRandomCropFixedAspectRatio', (_message.Message,), dict(
  DESCRIPTOR = _SSDRANDOMCROPFIXEDASPECTRATIO,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.SSDRandomCropFixedAspectRatio)
  ))
_sym_db.RegisterMessage(SSDRandomCropFixedAspectRatio)

SSDRandomCropPadFixedAspectRatioOperation = _reflection.GeneratedProtocolMessageType('SSDRandomCropPadFixedAspectRatioOperation', (_message.Message,), dict(
  DESCRIPTOR = _SSDRANDOMCROPPADFIXEDASPECTRATIOOPERATION,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatioOperation)
  ))
_sym_db.RegisterMessage(SSDRandomCropPadFixedAspectRatioOperation)

SSDRandomCropPadFixedAspectRatio = _reflection.GeneratedProtocolMessageType('SSDRandomCropPadFixedAspectRatio', (_message.Message,), dict(
  DESCRIPTOR = _SSDRANDOMCROPPADFIXEDASPECTRATIO,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.SSDRandomCropPadFixedAspectRatio)
  ))
_sym_db.RegisterMessage(SSDRandomCropPadFixedAspectRatio)

ConvertClassLogitsToSoftmax = _reflection.GeneratedProtocolMessageType('ConvertClassLogitsToSoftmax', (_message.Message,), dict(
  DESCRIPTOR = _CONVERTCLASSLOGITSTOSOFTMAX,
  __module__ = 'rastervision.protos.tf_object_detection.preprocessor_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.ConvertClassLogitsToSoftmax)
  ))
_sym_db.RegisterMessage(ConvertClassLogitsToSoftmax)


# @@protoc_insertion_point(module_scope)



import inspect
import os
from importlib import import_module
from fnmatch import fnmatchcase

import rastervision as rv


class LoaderError(Exception):
    pass


class ExperimentLoader:
    def __init__(self,
                 experiment_args=None,
                 experiment_method_prefix='exp',
                 experiment_method_patterns=None,
                 experiment_name_patterns=None):
        if experiment_args is None:
            experiment_args = {}
        self.exp_args = experiment_args
        self.exp_method_prefix = experiment_method_prefix
        self.exp_method_patterns = experiment_method_patterns
        self.exp_name_patterns = experiment_name_patterns

        self._top_level_dir = os.path.abspath(os.curdir)

    def _get_name_from_path(self, path):
        """Gets an importable  name from a path.

        Note: This code is from the python unittest library
        """
        if path == self._top_level_dir:
            return '.'
        path = os.path.splitext(os.path.normpath(path))[0]

        _relpath = os.path.relpath(path, self._top_level_dir)
        assert not os.path.isabs(_relpath), 'Path must be within the project'
        assert not _relpath.startswith('..'), 'Path must be within the project'

        name = _relpath.replace(os.path.sep, '.')
        return name

    def load_from_file(self, path):
        """Loads experiments and commands from an ExperimentSet contained
        in the given file.

        Returns a tuple (experiments, commands)"""
        name = self._get_name_from_path(path)
        return self.load_from_module(name)

    def load_from_module(self, name):
        """Loads experiments and commands from an ExperimentSet contained
        in the given module.

        Returns a tuple (experiments, commands)"""
        experiments, commands = [], []
        module = import_module(name)
        for name, obj in inspect.getmembers(module):
            if inspect.isclass(obj) and issubclass(obj, rv.ExperimentSet):
                experiment_set = obj()
                es, cs = self.load_from_set(experiment_set)
                experiments += es
                commands += cs
        return (experiments, commands)

    def load_from_set(self, experiment_set):
        return self.load_from_sets([experiment_set])

    def load_from_sets(self, experiment_sets):
        experiments = []
        commands = []
        for experiment_set in experiment_sets:
            for attrname in dir(experiment_set):
                include_method = True
                if not attrname.startswith(self.exp_method_prefix):
                    include_method = False
                exp_func = getattr(experiment_set, attrname)
                if not callable(exp_func):
                    include_method = False

                if include_method:
                    full_name = '%s.%s' % (experiment_set.__module__,
                                           exp_func.__qualname__)

                    if self.exp_method_patterns:
                        include_method = any(
                            fnmatchcase(full_name, pattern)
                            for pattern in self.exp_method_patterns)

                    if include_method:
                        es, cs = self.load_from_experiment(exp_func, full_name)
                        experiments.extend(es)
                        commands.extend(cs)

        if self.exp_name_patterns:
            # Avoid running commands if experiment names are used to filter
            commands = []

            def include(e):
                return any(
                    fnmatchcase(e.id, pattern)
                    for pattern in self.exp_name_patterns)

            experiments = list(filter(include, experiments))

        return (experiments, commands)

    def load_from_experiment(self, exp_func, full_name):
        experiments, commands = [], []
        kwargs = {}
        params = inspect.signature(exp_func).parameters.items()
        required_params = [
            key for key, param in params
            if param.default == inspect.Parameter.empty
        ]
        missing_params = set(required_params) - set(self.exp_args.keys())
        if missing_params:
            raise LoaderError('Missing required parameters '
                              'for experiment method '
                              '{}: "{}"'.format(full_name,
                                                '", "'.join(missing_params)))
        for key, param in params:
            if key in self.exp_args:
                kwargs[key] = self.exp_args[key]

        exp = exp_func(**kwargs)
        if not isinstance(exp, list):
            exp = [exp]

        for o in exp:
            if isinstance(o, rv.CommandConfig):
                commands.append(o)
            elif isinstance(o, rv.ExperimentConfig):
                experiments.append(o)
            else:
                raise LoaderError(
                    'Unknown type for experiment or command: {}'.format(
                        type(o)))

        return (experiments, commands)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rastervision/protos/scene.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rastervision.protos import raster_source_pb2 as rastervision_dot_protos_dot_raster__source__pb2
from rastervision.protos import label_source_pb2 as rastervision_dot_protos_dot_label__source__pb2
from rastervision.protos import label_store_pb2 as rastervision_dot_protos_dot_label__store__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rastervision/protos/scene.proto',
  package='rv.protos',
  syntax='proto2',
  serialized_pb=_b('\n\x1frastervision/protos/scene.proto\x12\trv.protos\x1a\'rastervision/protos/raster_source.proto\x1a&rastervision/protos/label_source.proto\x1a%rastervision/protos/label_store.proto\"\xf0\x01\n\x0bSceneConfig\x12\n\n\x02id\x18\x01 \x02(\t\x12\x34\n\rraster_source\x18\x02 \x02(\x0b\x32\x1d.rv.protos.RasterSourceConfig\x12?\n\x19ground_truth_label_source\x18\x03 \x01(\x0b\x32\x1c.rv.protos.LabelSourceConfig\x12;\n\x16prediction_label_store\x18\x04 \x01(\x0b\x32\x1b.rv.protos.LabelStoreConfig\x12\x0f\n\x07\x61oi_uri\x18\x05 \x01(\t\x12\x10\n\x08\x61oi_uris\x18\x06 \x03(\t')
  ,
  dependencies=[rastervision_dot_protos_dot_raster__source__pb2.DESCRIPTOR,rastervision_dot_protos_dot_label__source__pb2.DESCRIPTOR,rastervision_dot_protos_dot_label__store__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SCENECONFIG = _descriptor.Descriptor(
  name='SceneConfig',
  full_name='rv.protos.SceneConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='rv.protos.SceneConfig.id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raster_source', full_name='rv.protos.SceneConfig.raster_source', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ground_truth_label_source', full_name='rv.protos.SceneConfig.ground_truth_label_source', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prediction_label_store', full_name='rv.protos.SceneConfig.prediction_label_store', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aoi_uri', full_name='rv.protos.SceneConfig.aoi_uri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aoi_uris', full_name='rv.protos.SceneConfig.aoi_uris', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=407,
)

_SCENECONFIG.fields_by_name['raster_source'].message_type = rastervision_dot_protos_dot_raster__source__pb2._RASTERSOURCECONFIG
_SCENECONFIG.fields_by_name['ground_truth_label_source'].message_type = rastervision_dot_protos_dot_label__source__pb2._LABELSOURCECONFIG
_SCENECONFIG.fields_by_name['prediction_label_store'].message_type = rastervision_dot_protos_dot_label__store__pb2._LABELSTORECONFIG
DESCRIPTOR.message_types_by_name['SceneConfig'] = _SCENECONFIG

SceneConfig = _reflection.GeneratedProtocolMessageType('SceneConfig', (_message.Message,), dict(
  DESCRIPTOR = _SCENECONFIG,
  __module__ = 'rastervision.protos.scene_pb2'
  # @@protoc_insertion_point(class_scope:rv.protos.SceneConfig)
  ))
_sym_db.RegisterMessage(SceneConfig)


# @@protoc_insertion_point(module_scope)



from typing import (List, Union)

import numpy as np

from rastervision.core.box import Box
from rastervision.core.class_map import ClassMap
from rastervision.data import ActivateMixin
from rastervision.data.label import SemanticSegmentationLabels
from rastervision.data.label_source import LabelSource, SegmentationClassTransformer
from rastervision.data.raster_source import RasterSource


class SemanticSegmentationLabelSource(ActivateMixin, LabelSource):
    """A read-only label source for semantic segmentation."""

    def __init__(self, source: RasterSource, rgb_class_map: ClassMap = None):
        """Constructor.

        Args:
            source: (RasterSource) A raster source that returns a single channel
                raster with class_ids as values, or a 3 channel raster with
                RGB values that are mapped to class_ids using the rgb_class_map
            rgb_class_map: (ClassMap) with color values filled in. Optional and used to
                transform RGB values to class ids. Only use if the raster source
                is RGB.
        """
        self.source = source
        self.class_transformer = None
        if rgb_class_map is not None:
            self.class_transformer = SegmentationClassTransformer(
                rgb_class_map)

    def enough_target_pixels(self, window: Box, target_count_threshold: int,
                             target_classes: List[int]) -> bool:
        """Given a window, answer whether the window contains enough pixels in
        the target classes.

        Args:
             window: The larger window from-which the sub-window will
                  be clipped.
             target_count_threshold:  Minimum number of target pixels.
             target_classes: The classes of interest.  The given
                  window is examined to make sure that it contains a
                  sufficient number of target pixels.
        Returns:
             True (the window does contain interesting pixels) or False.
        """
        raw_labels = self.source.get_raw_chip(window)
        if self.class_transformer is not None:
            labels = self.class_transformer.rgb_to_class(raw_labels)
        else:
            labels = np.squeeze(raw_labels)

        target_count = 0
        for class_id in target_classes:
            target_count = target_count + (labels == class_id).sum()

        return target_count >= target_count_threshold

    def get_labels(self, window: Union[Box, None] = None,
                   chip_size=1000) -> SemanticSegmentationLabels:
        """Get labels for a window.

        To avoid running out of memory, if window is None and defaults to using the full
        extent, a set of sub-windows of size chip_size are used which cover the full
        extent with no overlap.

        Args:
             window: Either None or a window given as a Box object. Uses full extent of
                scene if window is not provided.
             chip_size: size of sub-windows to use if full extent is used (in
                units of pixels)
        Returns:
             SemanticSegmentationLabels
        """

        def label_fn(_window):
            raw_labels = self.source.get_raw_chip(_window)

            if self.class_transformer is not None:
                labels = self.class_transformer.rgb_to_class(raw_labels)
            else:
                labels = np.squeeze(raw_labels)

            return labels

        windows = [window]
        if window is None:
            window = self.source.get_extent()
            windows = window.get_windows(chip_size, chip_size)

        return SemanticSegmentationLabels(windows, label_fn)

    def _subcomponents_to_activate(self):
        return [self.source]

    def _activate(self):
        pass

    def _deactivate(self):
        pass



from abc import (abstractmethod)
import logging

from rastervision.evaluation import Evaluator
from rastervision.data import ActivateMixin

log = logging.getLogger(__name__)


class ClassificationEvaluator(Evaluator):
    """Evaluates predictions for a set of scenes.
    """

    def __init__(self, class_map, output_uri):
        self.class_map = class_map
        self.output_uri = output_uri
        self.eval = None

    @abstractmethod
    def create_evaluation(self):
        pass

    def process(self, scenes, tmp_dir):
        evaluation = self.create_evaluation()

        for scene in scenes:
            log.info('Computing evaluation for scene {}...'.format(scene.id))
            label_source = scene.ground_truth_label_source
            label_store = scene.prediction_label_store
            with ActivateMixin.compose(label_source, label_store):
                ground_truth = label_source.get_labels()
                predictions = label_store.get_labels()

                if scene.aoi_polygons:
                    # Filter labels based on AOI.
                    ground_truth = ground_truth.filter_by_aoi(
                        scene.aoi_polygons)
                    predictions = predictions.filter_by_aoi(scene.aoi_polygons)
                scene_evaluation = self.create_evaluation()
                scene_evaluation.compute(ground_truth, predictions)
                evaluation.merge(scene_evaluation, scene_id=scene.id)
        evaluation.save(self.output_uri)
        self.eval = evaluation



import logging

from shapely.geometry import shape, mapping
from shapely.strtree import STRtree

from rastervision.data import ActivateMixin, GeoJSONVectorSource
from rastervision.evaluation import (ClassificationEvaluator,
                                     SemanticSegmentationEvaluation)

log = logging.getLogger(__name__)


def filter_geojson_by_aoi(geojson, aoi_polygons):
    # Note that this ignores class_id but that's ok because each prediction GeoJSON file
    # covers a single class_id. But, this may change in the future.
    tree = STRtree([shape(f['geometry']) for f in geojson['features']])
    filtered_shapes = []
    for aoi_poly in aoi_polygons:
        shapes_in_aoi = tree.query(aoi_poly)
        for s in shapes_in_aoi:
            s_int = s.intersection(aoi_poly)
            filtered_shapes.append(s_int)

    features = [{
        'type': 'feature',
        'geometry': mapping(s)
    } for s in filtered_shapes]

    return {'type': 'FeatureCollection', 'features': features}


class SemanticSegmentationEvaluator(ClassificationEvaluator):
    """Evaluates predictions for a set of scenes.
    """

    def __init__(self, class_map, output_uri, vector_output_uri):
        super().__init__(class_map, output_uri)
        self.vector_output_uri = vector_output_uri

    def create_evaluation(self):
        return SemanticSegmentationEvaluation(self.class_map)

    def process(self, scenes, tmp_dir):
        evaluation = self.create_evaluation()
        vect_evaluation = self.create_evaluation()

        for scene in scenes:
            log.info('Computing evaluation for scene {}...'.format(scene.id))
            label_source = scene.ground_truth_label_source
            label_store = scene.prediction_label_store
            with ActivateMixin.compose(label_source, label_store):
                ground_truth = label_source.get_labels()
                predictions = label_store.get_labels()

                if scene.aoi_polygons:
                    # Filter labels based on AOI.
                    ground_truth = ground_truth.filter_by_aoi(
                        scene.aoi_polygons)
                    predictions = predictions.filter_by_aoi(scene.aoi_polygons)
                scene_evaluation = self.create_evaluation()
                scene_evaluation.compute(ground_truth, predictions)
                evaluation.merge(scene_evaluation, scene_id=scene.id)

            if hasattr(label_source, 'source') and hasattr(
                    label_source.source, 'vector_source') and hasattr(
                        label_store, 'vector_output'):
                gt_geojson = label_source.source.vector_source.get_geojson()
                for vo in label_store.vector_output:
                    pred_geojson_uri = vo['uri']
                    mode = vo['mode']
                    class_id = vo['class_id']
                    pred_geojson_source = GeoJSONVectorSource(
                        pred_geojson_uri,
                        scene.raster_source.get_crs_transformer())
                    pred_geojson = pred_geojson_source.get_geojson()

                    if scene.aoi_polygons:
                        gt_geojson = filter_geojson_by_aoi(
                            gt_geojson, scene.aoi_polygons)
                        pred_geojson = filter_geojson_by_aoi(
                            pred_geojson, scene.aoi_polygons)

                    vect_scene_evaluation = self.create_evaluation()
                    vect_scene_evaluation.compute_vector(
                        gt_geojson, pred_geojson, mode, class_id)
                    vect_evaluation.merge(
                        vect_scene_evaluation, scene_id=scene.id)

        if not evaluation.is_empty():
            evaluation.save(self.output_uri)
        if not vect_evaluation.is_empty():
            vect_evaluation.save(self.vector_output_uri)



import rastervision as rv
from rastervision.plugin import PluginRegistry
from rastervision.protos.command_pb2 import CommandConfig as CommandConfigMsg
from rastervision.utils.files import load_json_config


class CommandRunner:
    @staticmethod
    def run(command_config_uri):
        msg = load_json_config(command_config_uri, CommandConfigMsg())
        CommandRunner.run_from_proto(msg)

    def run_from_proto(msg):
        PluginRegistry.get_instance().add_plugins_from_proto(msg.plugins)
        command_config = rv.command.CommandConfig.from_proto(msg)
        command = command_config.create_command()
        command.run()



import os
import shutil

from google.protobuf import json_format


def file_to_str(file_path):
    with open(file_path, 'r') as file_buffer:
        return file_buffer.read()


def load_json_config(uri, message):
    return json_format.Parse(file_to_str(uri), message)


def make_dir(path, check_empty=False, force_empty=False, use_dirname=False):
    directory = path
    if use_dirname:
        directory = os.path.dirname(path)

    if force_empty and os.path.isdir(directory):
        shutil.rmtree(directory)

    os.makedirs(directory, exist_ok=True)

    is_empty = len(os.listdir(directory)) == 0
    if check_empty and not is_empty:
        raise ValueError(
            '{} needs to be an empty directory!'.format(directory))


def predict(batch, model):
    # Apply same transform to input as when training.
    # TODO be able to configure this transform and the one in the
    # training generator.
    return model.predict(batch / 255.0)



# flake8: noqa

from rastervision.data.vector_source.geojson_vector_source import *
from rastervision.data.vector_source.geojson_vector_source_config import *
from rastervision.data.vector_source.vector_tile_vector_source import *
from rastervision.data.vector_source.vector_tile_vector_source_config import *
from rastervision.data.vector_source.vector_source import *
from rastervision.data.vector_source.vector_source_config import *
from rastervision.data.vector_source.class_inference import *
